@@ -212,23 +212,24 @@ class Sylo:
         self.tasks = get_tasks(date)
         self.input_loop()
 
-    def new_task_menu(self):
+    def new_task_menu(self, date: str):
         clear_screen()
         task = Task()
+        self.tasks = get_tasks(date)
         display.print_header_small()
-        display.print_tasks(get_tasks(self.tasks))
+        display.print_tasks(self.tasks)
         display.print_add_task_or_quit()
         usr_input = input(cursor)
         if usr_input.lower() == "q":
             self.input_loop()
         if usr_input == "":
             display.print_new_task()
-            task.description = input(cursor)
+            task.description = input('Description >> ')
             task.write_task_to_file()
             display.print_another_task()
             another_yn = input(cursor)
             if another_yn.lower() == "y":
-                self.new_task_menu()
+                self.new_task_menu(date)
             else:
                 self.input_loop()
 
@@ -312,7 +313,7 @@ class Sylo:
         while response.lower() == "a":
             self.task_menu()
         while response.lower() == "n":
-            self.new_task_menu()
+            self.new_task_menu(TODAY_STR)
         while response == "":
             self.timer_loop(timer)
 
